pub enum DiagnosticKind {
Fused,
Wrap,
Long,
}Expand description
Kind of a line-level check diagnostic.
Variants
Fused
Splitter finds more than one sentence on a prose line.
Wrap
Mid-clause continuation: the previous prose line does not end a clause and this line starts with a lowercase non-connector word.
Long
Advisory: prose line exceeds the width threshold and has a clause boundary where a break could go.
Implementations