pub struct FormatTextResult {
pub formatted: String,
}Fields
formatted: StringTrait Implementations
Sourceimpl Debug for FormatTextResult
impl Debug for FormatTextResult
Sourceimpl JsonSchema for FormatTextResult
impl JsonSchema for FormatTextResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FormatTextResult
impl RefUnwindSafe for FormatTextResult
impl Send for FormatTextResult
impl Sync for FormatTextResult
impl Unpin for FormatTextResult
impl UnsafeUnpin for FormatTextResult
impl UnwindSafe for FormatTextResult