pub struct SplitSentencesResult {
pub sentences: Vec<String>,
}Fields
sentences: Vec<String>Trait Implementations
Sourceimpl Debug for SplitSentencesResult
impl Debug for SplitSentencesResult
Sourceimpl JsonSchema for SplitSentencesResult
impl JsonSchema for SplitSentencesResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SplitSentencesResult
impl RefUnwindSafe for SplitSentencesResult
impl Send for SplitSentencesResult
impl Sync for SplitSentencesResult
impl Unpin for SplitSentencesResult
impl UnsafeUnpin for SplitSentencesResult
impl UnwindSafe for SplitSentencesResult