pub fn unified_diff(path: &str, original: &str, formatted: &str) -> StringExpand description
Produce a unified diff between original and formatted text using imara-diff’s histogram algorithm (same as git’s default).
Returns an empty string if the texts are identical.