Functions
- check_
file - Check if a file needs formatting. Returns
Noneif already formatted, orSome(unified_diff)if changes are needed. - format_
file - Format a file on disk, returning the formatted text. Auto-detects format from the file extension.
- format_
file_ with - Format a file with extra abbreviations from a project config.
- format_
in_ place - Format a file in-place. Returns
trueif the file was changed.