Re-exports
pub use span::ByteSpan;pub use span::CodeSpans;pub use span::Line;pub use span::RegionOrigin;pub use span::SpannedRegion;pub use span::flush_prose_spanned;pub use span::iter_lines;pub use span::push_prose_line;
Modules
- latex
- markdown
- org
- pandoc
- Pandoc parses first; snapper reflows second.
- plaintext
- rst
- span
- Source-byte spans for splice reflow.
Enums
- Region
- A region of text classified by a format parser.
Traits
- Format
Parser - Trait for format-specific parsers that classify text into regions.
Functions
- check_
pragma - Check if a line contains a snapper pragma. Returns Some(false) for “snapper:off”, Some(true) for “snapper:on”, None otherwise.
- flush_
prose - Flush accumulated prose into the region list, clearing the buffer.
- parser_
for_ format - Create the appropriate parser for a given format (built-in lists only).
- parser_
for_ format_ config - Create a parser, applying
[latex]extras fromconfigwhen present. - source_
line_ payloads - Per-source-line prose payload from the same
parse_fullwalk format uses.